<?php

/*
Plugin Name: GetSimple News Manager
Description: A basic news manager
Version: 1.2.1
Author: Rogier Koppejan
*/

# get correct id for plugin
$thisfile = basename(__FILE__, ".php");

# register plugin
register_plugin(
  $thisfile,
  'News Manager',
  '1.2.1',
  'Rogier Koppejan',
  '#',
  'A basic news manager',
  'pages',
  'news_manager'
);


# hooks
add_action('pages-sidebar', 'createSideMenu', array($thisfile, 'News Manager'));

# definitions
define('EXCERPTLENGTH', 50);
define('ARTICLEDATA', GSDATAPATH  . 'articles/');

if (EXCERPTLENGTH < 1) die ('News Manager: Incorrect value set for EXCERPTLENGTH');

############################### ADMIN FUNCTIONS ################################


/*******************************************************
 * @function news_manager
 * @action main function, creates, edits or deletes articles
 */
function news_manager() {
  if (!file_exists(ARTICLEDATA)) {
    echo '<h3>News Manager</h3><p>The directory "<i>GSDATAPATH/articles</i>"
    does not exist. It is required for this plugin to function properly.
    Please create it manually and make sure it is writable.</p>';
  } elseif (isset($_GET['edit'])) {
    $id = empty($_GET['edit']) ? uniqid() : $_GET['edit'];
    edit_article($id);
  } elseif (isset($_GET['delete'])) {
    $id = $_GET['delete'];
    delete_article($id);
  } elseif (isset($_POST['submit'])) {
    save_article();
  } else {
    article_overview();
  }
}


/*******************************************************
 * @function article_overview
 * @action list articles and provide options for editing
 */
function article_overview() {
  $articles = get_articles();
  ?>
  <label>News Manager</label>
  <div class="edit-nav" >
    <a href="load.php?id=news_manager&edit">Create New Article</a>
    <div class="clear"></div>
  </div>
  <?php
  if (!empty($articles)) {
    echo '<table class="highlight">';
    foreach ($articles as $article) {
      $id = basename($article, ".xml");
      $file = ARTICLEDATA . $article;
      $data = @getXML($file);
      $date = $data->date;
      $title = html_entity_decode($data->title, ENT_QUOTES, 'UTF-8');
      ?>
      <tr>
        <td>
          <a href="load.php?id=news_manager&edit=<?php echo $id; ?>" title="Edit article: <?php echo $title; ?>">
            <?php echo $title; ?>
          </a>
        </td>
        <td style="text-align: right;">
          <span><?php echo $date; ?></span>
        </td>
        <td class="delete">
          <a href="load.php?id=news_manager&delete=<?php echo $id; ?>" class="delconfirm" title="Delete article: <?php echo $title; ?>?">
            X
          </a>
        </td>
      </tr>
      <?php
    }
    echo '</table>';
  }
  echo '<p><b>' . count($articles) . '</b> articles</p>';
}


/*******************************************************
 * @function edit_article
 * @param $id - unique article id
 * @action edit or create new articles
 */
function edit_article($id) {
  $file = ARTICLEDATA . $id . '.xml';
  $data = @getXML($file);
  $title = @stripslashes($data->title);
  $content = @stripslashes($data->content);
  ?>
  <h3><?php if (empty($data)) echo 'Create New'; else echo 'Edit'; ?> Article</h3>
  <form class="largeform" id="editform" action="load.php?id=news_manager" method="post" accept-charset="utf-8">
    <p>
      <input name="id" type="hidden" value="<?php echo $id; ?>" />
    <p>
      <input class="text title" name="post-title" type="text" value="<?php echo @$title; ?>" />
    </p>
    <p>
      <textarea name="post-content"><?php echo @$content; ?></textarea>
    </p>
    <p>
      <input name="submit" type="submit" class="submit" value="Save Article" />
      &nbsp;&nbsp;or&nbsp;&nbsp;
      <a href="load.php?id=news_manager" class="cancel" title="Cancel">Cancel</a>
    </p>
  </form>
  <?php
  // Include ckeditor
  if (isset($_GET['id']) and $_GET['id'] == "news_manager") {
    if (file_exists(GSDATAOTHERPATH . 'cp_settings.xml')) {
      $file = GSDATAOTHERPATH .'cp_settings.xml';
      $data = getXML($file);
      $HTMLEDITOR = $data->HTMLEDITOR;
    }
    if (isset($HTMLEDITOR) && $HTMLEDITOR != '') {
      $TOOLBAR = "['Bold', 'Italic', 'Underline', 'NumberedList', 'BulletedList', 'JustifyLeft', 'JustifyCenter', 'JustifyRight', 'JustifyBlock', 'Link', 'Unlink', 'Image', 'RemoveFormat', 'Source']";
      $EDLANG = defined('GSEDITORLANG') ? GSEDITORLANG : 'en';
      ?>
      <script type="text/javascript" src="template/js/ckeditor/ckeditor.js"></script>
      <script type="text/javascript">
        var editor = CKEDITOR.replace( 'post-content', {
          skin : 'getsimple',
          forcePasteAsPlainText : true,
          language : '<?php echo $EDLANG; ?>',
          defaultLanguage : '<?php echo $EDLANG; ?>',
          entities : true,
          uiColor : '#FFFFFF',
          height: '300',
          toolbar :
          [
          <?php echo $TOOLBAR; ?>
          ]
        });
      </script>
      <?php
    }
  }
}


/*******************************************************
 * @function save_article
 * @action write $_POST data to a file
 */
function save_article() {
  $id = $_POST['id'];
  $file = ARTICLEDATA . $id . '.xml';
  $title = htmlentities($_POST['post-title'], ENT_QUOTES, 'UTF-8');
  $content = htmlentities($_POST['post-content'], ENT_QUOTES, 'UTF-8');

  if (!file_exists($file)) {
    $date = date('j M Y');
  } else {
    $data = @getXML($file);
    $date = $data->date;
  }

  $xml = @new SimpleXMLElement('<?xml version="1.0" encoding="UTF-8"?><item></item>');
  $xml->addChild('title', $title);
  $xml->addChild('date', $date);
  $xml->addChild('content', $content);
  XMLsave($xml, $file);

  if (!is_writable($file))
    echo '<div class="error">Unable to write article data to file</div>';
  else
    echo '<div class="updated">The article has been succesfully saved</div>';

  article_overview();
}


/*******************************************************
 * @function delete_article
 * @param $id - unique article id
 * @action deletes the requested article
 */
function delete_article($id) {
  $file = ARTICLEDATA . $id . '.xml';
  if (file_exists($file))
    unlink($file);
  if (file_exists($file))
    echo '<div class="error">Unable to delete the article</div>';
  else
    echo '<div class="updated">The article has been deleted</div>';
  article_overview();
}


############################### SITE FUNCTIONS #################################


/*******************************************************
 * @function show_articles
 * @param $n - the number of articles to show on one page
 * @action runs the news plugin on the theme/site page
 */
function show_articles($n = NULL) {
  if (isset($_GET['article'])) {
    $id = $_GET['article'];
    show_article($id);
  } else {
    $articles = get_articles();
    if (!empty($articles)) {
      if (isset($n) && $n > 0) {
        $index = isset($_GET['page']) ? $_GET['page'] : 0;
        $pages = array_chunk($articles, $n);
        if (is_numeric($index) && $index >= 0 && $index < sizeof($pages))
          $articles = $pages[$index];
        else
          $articles = array();
      }
      foreach ($articles as $article) {
        $id = basename($article, ".xml");
        show_article($id, TRUE);
      }
      if (!empty($articles) && isset($pages) && sizeof($pages) > 1)
        show_navigation($index, sizeof($pages));
    }
  }
}


/*******************************************************
 * @function show_article
 * param $id - unique article id
 * param $excerpt - if TRUE, print only a short article summary
 * @action prints the article with given id on theme/site page
 */
function show_article($id, $excerpt=FALSE) {
  $file = ARTICLEDATA . $id . '.xml';
  $data = getXML($file);
  if (!empty($data)) {
    $date = $data->date;
    $title = stripslashes(htmlspecialchars_decode($data->title, ENT_QUOTES));
    $content = stripslashes(htmlspecialchars_decode($data->content, ENT_QUOTES));
    if ($excerpt) {
      $content = get_excerpt($content);
      $url = get_page_url(TRUE);
      $url .= preg_match('/\?/', $url) ? '&' : '?';
      $url .= "article=$id";
    }
    ?>
    <div class="article">
      <h3 class="article_title">
        <?php echo $excerpt ? "<a href=\"$url\">$title</a>" : $title; ?>
      </h3>
      <p class="article_date">Posted on: <?php echo $date; ?></p>
      <div class="article_content"><?php echo $content; ?></div>
    </div>
    <?php
  } else {
    echo '<p>The requested article does not exist.</p>';
  }
}


/*******************************************************
 * @function show_navigation
 * param $index - current page index
 * param $n - total number of pages
 * @action provides links to navigate between article pages
 */
function show_navigation($index, $n) {
  $url = get_page_url(TRUE);                                // url
  $del = preg_match('/\?/', $url) ? '&' : '?';              // delimiter
  echo '<div class="article_navigation">';
  if ($index < $n - 1) {
    ?>
    <div class="alignleft">
      <a href="<?php echo $url . $del . 'page=' . ($index+1); ?>">&larr; Older Articles</a>
    </div>
    <?php
  }
  if ($index > 0) {
    ?>
    <div class="alignright">
      <a href="<?php echo ($index > 1) ? $url . $del . 'page=' . ($index-1) : $url; ?>">Newer Articles &rarr;</a>
    </div>
    <?php
  }
  echo '</div><br />';
}


############################## COMMON FUNCTIONS ################################


/*******************************************************
 * @function get_articles
 * @returns returns a list of articles in the folder ARTICLEDATA
 */
function get_articles() {
  $articles = array();
  $files = getFiles(ARTICLEDATA);
  foreach ($files as $file) {
    if (is_file(ARTICLEDATA . $file) && preg_match("/.xml$/", $file)) {
      $articles[] = $file;
    }
  }
  sort($articles);
  return array_reverse($articles);
}


/*******************************************************
 * @function get_excerpt
 * @param $content - string containing article content
 * @returns returns the first $n tokens of string $content
 */
function get_excerpt($content) {
  $tokens = explode(' ', $content);
  if (count($tokens) < EXCERPTLENGTH)
    $excerpt = $content;
  else {
    array_splice($tokens, EXCERPTLENGTH);
    $excerpt = implode(' ', $tokens) . ' [...]';
  }
  return $excerpt;
}



?>
